import * as formUtils from '../form';
import exampleServices from '../../__tests__/example-services';
var fieldNames = ['fieldA', 'fieldB', 'fieldC'];
test('should handle no field values', function () {
    var defaults = formUtils.getDefaultFormValues(undefined);
    expect(defaults).toEqual({});
});
test('should default all fields to blank if no parameters have been provided', function () {
    var defaults = formUtils.getDefaultFormValues(fieldNames);
    expect(defaults).toEqual({
        fieldA: '',
        fieldB: '',
        fieldC: '',
    });
});
test('should default form fields to provided parameter values', function () {
    var defaults = formUtils.getDefaultFormValues(fieldNames, { fieldB: 'bValue', fieldC: 'cValue' });
    expect(defaults).toEqual({
        fieldA: '',
        fieldB: 'bValue',
        fieldC: 'cValue',
    });
});
test('should lookup the form configuration for the active service/action', function () {
    var activeForm = formUtils.getActiveActionForm(exampleServices, 'serviceA', 'typeB');
    expect(activeForm).toEqual(['fieldC', 'fieldD']);
});
test('should handle lookup for a service/action with no form', function () {
    var activeForm = formUtils.getActiveActionForm(exampleServices, 'serviceB', 'typeF');
    expect(activeForm).toEqual([]);
});
test('should return [] if there is no active action', function () {
    var activeForm = formUtils.getActiveActionForm(exampleServices, undefined, undefined);
    expect(activeForm).toEqual([]);
});
//# sourceMappingURL=form.test.js.map